@@ -46,9 +46,9 @@ def create_depgraph_params(myopts, myaction):
 	myparams["ignore_soname_deps"] = myopts.get(
 		"--ignore-soname-deps", "y")
 
-	dynamic_deps = myopts.get("--dynamic-deps")
-	if dynamic_deps is not None:
-		myparams["dynamic_deps"] = dynamic_deps
+	dynamic_deps = myopts.get("--dynamic-deps", "y") != "n"
+	if dynamic_deps:
+		myparams["dynamic_deps"] = True
 
 	if myaction == "remove":
 		myparams["remove"] = True
@@ -127,10 +127,8 @@ def create_depgraph_params(myopts, myaction):
 	if changed_deps is not None:
 		myparams['changed_deps'] = changed_deps
 
-	changed_deps_report = myopts.get('--changed-deps-report')
-	if (changed_deps_report != 'n' and
-		not (myaction == 'remove' or '--usepkgonly' in myopts) and
-		deep is True and '--update' in myopts):
+	changed_deps_report = myopts.get('--changed-deps-report', 'n') == 'y'
+	if changed_deps_report:
 		myparams['changed_deps_report'] = True
 
 	if myopts.get("--selective") == "n":
